@@ -7,7 +7,7 @@
  * published by the Free Software Foundation; either version 2 of
  * the License or (at your option) version 3 or any later version
  * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy 
+ * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,6 +25,7 @@
 #include <KApplication>
 #include <KCmdLineArgs>
 #include <KCursor>
+#include <KDebug>
 #include <KFileDialog>      //::open()
 #include <KGlobalSettings> //::timerEvent()
 #include <KIO/NetAccess>
@@ -36,6 +37,7 @@
 #include <KToolBar>
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
+#include <KProtocolInfo>
 
 #include <Phonon/VideoWidget>
 
@@ -61,7 +63,6 @@
 #include "dbus/playerDbusHandler.h"
 #include "dbus/rootDbusHandler.h"
 #include "dbus/trackListDbusHandler.h"
-#include "debug.h"
 #include "extern.h"         //dialog creation function definitions
 #include "fullScreenToolBarHandler.h"
 #include "messageBox.h"
@@ -86,7 +87,7 @@ namespace Dragon {
 MainWindow::MainWindow()
         : KXmlGuiWindow()
         , m_mainView( 0 )
-        , m_audioView(new AudioView(this) )
+        , m_audioView( 0 )
         , m_loadView( new LoadView(this) )
         , m_currentWidget( new QWidget(this) )
         , m_leftDock( 0 )
@@ -100,7 +101,6 @@ MainWindow::MainWindow()
         , m_toolbarIsHidden(false)
         , m_statusbarIsHidden(false)
 {
-    DEBUG_BLOCK
     s_instance = this;
     setMouseTracking( true );
 
@@ -111,12 +111,13 @@ MainWindow::MainWindow()
     videoWindow()->setMouseTracking( true );
 
     m_positionSlider = videoWindow()->newPositionSlider();
-    
+
     m_mainView->addWidget(m_loadView);
+    m_audioView = new AudioView(this);
     m_mainView->addWidget(m_audioView);
     m_mainView->addWidget(videoWindow());
     m_mainView->setCurrentWidget(m_loadView);
-    
+
     m_currentWidget = m_loadView;
 
     setCentralWidget( m_mainView );
@@ -131,14 +132,14 @@ MainWindow::MainWindow()
     statusBar()->setSizePolicy( QSizePolicy::Ignored, QSizePolicy::Maximum );
 
     setupActions();
-    
+
     //setStandardToolBarMenuEnabled( false ); //bah to setupGUI()!
     //toolBar()->show(); //it's possible it would be hidden, but we don't want that as no UI way to show it!
 
     {
         KActionCollection* ac = actionCollection();
         QMenu *menu = 0;
-        QAction *menuAction = 0; 
+        QAction *menuAction = 0;
         #define make_menu( name, text ) \
                 menu = new QMenu( text ); \
                 menuAction = menu->menuAction(); \
@@ -146,9 +147,9 @@ MainWindow::MainWindow()
                 menuAction->setEnabled( false ); \
                 connect( menu, SIGNAL(aboutToShow()), SLOT(aboutToShowMenu()) ); \
                 ac->addAction( menuAction->objectName(), menuAction );
-        make_menu( "aspect_ratio_menu", i18n( "Aspect &Ratio" ) );
-        make_menu( "audio_channels_menu", i18n( "&Audio Channels" ) );
-        make_menu( "subtitle_channels_menu", i18n( "&Subtitles" ) );
+        make_menu( QLatin1String( "aspect_ratio_menu" ), i18n( "Aspect &Ratio" ) );
+        make_menu( QLatin1String( "audio_channels_menu" ), i18n( "&Audio Channels" ) );
+        make_menu( QLatin1String( "subtitle_channels_menu" ), i18n( "&Subtitles" ) );
         #undef make_menu
 
         {
@@ -164,13 +165,13 @@ MainWindow::MainWindow()
                 ac->addAction( objectname, ratioAction ); \
                 connect( ratioAction, SIGNAL( triggered() ), this, SLOT( streamSettingChange() ) ); \
             }
-            make_ratio_action( i18n( "Determine &Automatically" ), "ratio_auto",  Phonon::VideoWidget::AspectRatioAuto );
-            make_ratio_action( i18n( "&4:3" ), "ratio_golden", Phonon::VideoWidget::AspectRatio4_3 );
-            make_ratio_action( i18n( "Ana&morphic (16:9)" ), "ratio_anamorphic", Phonon::VideoWidget::AspectRatio16_9 );
-            make_ratio_action( i18n( "&Window Size" ), "ratio_window", Phonon::VideoWidget::AspectRatioWidget );
+            make_ratio_action( i18n( "Determine &Automatically" ), QLatin1String( "ratio_auto" ),  Phonon::VideoWidget::AspectRatioAuto );
+            make_ratio_action( i18n( "&4:3" ), QLatin1String( "ratio_golden" ), Phonon::VideoWidget::AspectRatio4_3 );
+            make_ratio_action( i18n( "Ana&morphic (16:9)" ), QLatin1String( "ratio_anamorphic" ), Phonon::VideoWidget::AspectRatio16_9 );
+            make_ratio_action( i18n( "&Window Size" ), QLatin1String( "ratio_window" ), Phonon::VideoWidget::AspectRatioWidget );
             #undef make_ratio_action
-            ac->action( "ratio_auto" )->setChecked( true );
-            ac->action( "aspect_ratio_menu" )->menu()->addActions( m_aspectRatios->actions() );
+            ac->action( QLatin1String( "ratio_auto" ) )->setChecked( true );
+            ac->action( QLatin1String( "aspect_ratio_menu" ) )->menu()->addActions( m_aspectRatios->actions() );
         }
     }
 
@@ -180,25 +181,24 @@ MainWindow::MainWindow()
         toolBar()->setAllowedAreas( Qt::TopToolBarArea | Qt::BottomToolBarArea );
         toolBar()->setFloatable( false );
     }
-    KXMLGUIClient::stateChanged( "empty" );
+    KXMLGUIClient::stateChanged( QLatin1String( "empty" ) );
 
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
     if( args->count() || args->isSet( "play-dvd" ) || kapp->isSessionRestored() )
         //we need to resize the window, so we can't show the window yet
         init();
-    else 
+    else
     {
         //"faster" startup
         //TODO if we have a size stored for this video, do the "faster" route
         QTimer::singleShot( 0, this, SLOT(init()) );
-        QApplication::setOverrideCursor( Qt::WaitCursor ); 
+        QApplication::setOverrideCursor( Qt::WaitCursor );
     }
 }
 
 void
 MainWindow::init()
 {
-//     DEBUG_BLOCK
     //connect the stuff in loadView
     connect( m_loadView, SIGNAL(openDVDPressed()), this, SLOT(playDisc()) );
     connect( m_loadView, SIGNAL(openFilePressed()), this, SLOT(openFileDialog()) );
@@ -258,7 +258,6 @@ MainWindow::init()
 
 MainWindow::~MainWindow()
 {
-    DEBUG_BLOCK
     hide(); //so we appear to have quit, and then sound fades out below
     delete videoWindow(); //fades out sound in dtor
 }
@@ -270,7 +269,7 @@ void MainWindow::closeEvent (QCloseEvent *event)
     statusBar()->setHidden( m_statusbarIsHidden );
     toolBar()->setHidden( m_toolbarIsHidden );
     menuBar()->setHidden( false );
-    
+
     KMainWindow::closeEvent( event );
 }
 
@@ -287,7 +286,6 @@ void MainWindow::wheelEvent (QWheelEvent *event)
 void
 MainWindow::setupActions()
 {
-    DEBUG_BLOCK
 
     KActionCollection * const ac = actionCollection();
 
@@ -298,7 +296,7 @@ MainWindow::setupActions()
     #define addToAc( X ) ac->addAction( X->objectName(), X );
 
     KToggleFullScreenAction* toggleFullScreen = new KToggleFullScreenAction( this, ac );
-    toggleFullScreen->setObjectName( "fullscreen" );
+    toggleFullScreen->setObjectName( QLatin1String( "fullscreen" ) );
     toggleFullScreen->setShortcut( Qt::Key_F );
     toggleFullScreen->setAutoRepeat( false );
     connect( toggleFullScreen, SIGNAL( toggled( bool ) ), Dragon::mainWindow(), SLOT( setFullScreen( bool ) ) );
@@ -307,75 +305,75 @@ MainWindow::setupActions()
     new PlayAction( this, SLOT( play() ), ac );
     new VolumeAction( this, SLOT( toggleVolumeSlider( bool ) ), ac );
 
-    KAction* playerStop = new KAction( KIcon("media-playback-stop"), i18n("Stop"), ac );
-    playerStop->setObjectName( "stop" );
+    KAction* playerStop = new KAction( KIcon(QLatin1String( "media-playback-stop" )), i18n("Stop"), ac );
+    playerStop->setObjectName( QLatin1String( "stop" ) );
     playerStop->setShortcut( Qt::Key_S );
     connect( playerStop, SIGNAL( triggered() ), engine(), SLOT( stop() ) );
     addToAc( playerStop )
 
-    KToggleAction* mute = new KToggleAction( KIcon("player-volume-muted"), i18nc( "Mute the sound output", "Mute"), ac );
-    mute->setObjectName( "mute" );
+    KToggleAction* mute = new KToggleAction( KIcon(QLatin1String( "player-volume-muted" )), i18nc( "Mute the sound output", "Mute"), ac );
+    mute->setObjectName( QLatin1String( "mute" ) );
     mute->setShortcut( Qt::Key_M );
     connect( mute, SIGNAL( toggled( bool ) ), videoWindow(), SLOT( mute( bool ) ) );
     addToAc( mute )
 
-    KAction* resetZoom = new KAction( KIcon("zoom-fit-best"), i18n("Reset Video Scale"), ac );
-    resetZoom->setObjectName( "reset_zoom" );
+    KAction* resetZoom = new KAction( KIcon(QLatin1String( "zoom-fit-best" )), i18n("Reset Video Scale"), ac );
+    resetZoom->setObjectName( QLatin1String( "reset_zoom" ) );
     resetZoom->setShortcut( Qt::Key_Equal );
     connect( resetZoom, SIGNAL( triggered() ), videoWindow(), SLOT( resetZoom() ) );
     addToAc( resetZoom )
 
-    KAction* dvdMenu = new KAction( KIcon("media-optical-video"), i18n("Menu Toggle"), ac );
-    dvdMenu->setObjectName( "toggle_dvd_menu" );
+    KAction* dvdMenu = new KAction( KIcon(QLatin1String( "media-optical-video" )), i18n("Menu Toggle"), ac );
+    dvdMenu->setObjectName( QLatin1String( "toggle_dvd_menu" ) );
     dvdMenu->setShortcut( Qt::Key_R );
     connect( dvdMenu, SIGNAL( triggered() ), engine(), SLOT( toggleDVDMenu() ) );
     addToAc( dvdMenu )
 
     KAction* positionSlider = new KAction( i18n("Position Slider"), ac );
-    positionSlider->setObjectName( "position_slider" );
+    positionSlider->setObjectName( QLatin1String( "position_slider" ) );
     positionSlider->setDefaultWidget( m_positionSlider );
     addToAc( positionSlider )
 
     KAction* videoSettings = new KAction( i18n("Video Settings"), ac );
-    videoSettings->setObjectName( "video_settings" );
+    videoSettings->setObjectName( QLatin1String( "video_settings" ) );
     videoSettings->setCheckable( true );
     connect( videoSettings, SIGNAL( toggled( bool ) ), this, SLOT( toggleVideoSettings( bool ) ) );
     addToAc( videoSettings )
 
-    KAction* prev_chapter = new KAction( KIcon("media-skip-backward"), i18n("Previous Chapter"), ac );
-    prev_chapter->setObjectName( "prev_chapter" );
+    KAction* prev_chapter = new KAction( KIcon(QLatin1String( "media-skip-backward" )), i18n("Previous Chapter"), ac );
+    prev_chapter->setObjectName( QLatin1String( "prev_chapter" ) );
     prev_chapter->setShortcut( Qt::Key_Comma );
     connect( prev_chapter, SIGNAL( triggered() ), engine(), SLOT( prevChapter() ) );
     addToAc( prev_chapter )
 
-    KAction* next_chapter = new KAction( KIcon("media-skip-forward"), i18n("Next Chapter"), ac );
-    next_chapter->setObjectName( "next_chapter" );
+    KAction* next_chapter = new KAction( KIcon(QLatin1String( "media-skip-forward" )), i18n("Next Chapter"), ac );
+    next_chapter->setObjectName( QLatin1String( "next_chapter" ) );
     next_chapter->setShortcut( Qt::Key_Period );
     connect( next_chapter, SIGNAL( triggered() ), engine(), SLOT( nextChapter() ) );
     addToAc( next_chapter )
 
     // xgettext: no-c-format
-    KAction* tenPercentBack = new KAction( KIcon("media-seek-backward"), i18n("Return 10% Back"), ac );
-    tenPercentBack->setObjectName( "ten_percent_back" );
+    KAction* tenPercentBack = new KAction( KIcon(QLatin1String( "media-seek-backward" )), i18n("Return 10% Back"), ac );
+    tenPercentBack->setObjectName( QLatin1String( "ten_percent_back" ) );
     tenPercentBack->setShortcut( Qt::Key_PageUp );
     connect( tenPercentBack, SIGNAL( triggered() ), engine(), SLOT( tenPercentBack() ) );
     addToAc( tenPercentBack )
 
     // xgettext: no-c-format
-    KAction* tenPercentForward = new KAction( KIcon("media-seek-forward"), i18n("Go 10% Forward"), ac );
-    tenPercentForward->setObjectName( "ten_percent_forward" );
+    KAction* tenPercentForward = new KAction( KIcon(QLatin1String( "media-seek-forward" )), i18n("Go 10% Forward"), ac );
+    tenPercentForward->setObjectName( QLatin1String( "ten_percent_forward" ) );
     tenPercentForward->setShortcut( Qt::Key_PageDown );
     connect( tenPercentForward, SIGNAL( triggered() ), engine(), SLOT( tenPercentForward() ) );
     addToAc( tenPercentForward )
 
-    KAction* tenSecondsBack = new KAction( KIcon("media-seek-backward"), i18n("Return 10 Seconds Back"), ac );
-    tenSecondsBack->setObjectName( "ten_seconds_back" );
+    KAction* tenSecondsBack = new KAction( KIcon(QLatin1String( "media-seek-backward" )), i18n("Return 10 Seconds Back"), ac );
+    tenSecondsBack->setObjectName( QLatin1String( "ten_seconds_back" ) );
     tenSecondsBack->setShortcut( Qt::Key_Minus );
     connect( tenSecondsBack, SIGNAL( triggered() ), engine(), SLOT( tenSecondsBack() ) );
     addToAc( tenSecondsBack )
 
-    KAction* tenSecondsForward = new KAction( KIcon("media-seek-forward"), i18n("Go 10 Seconds Forward"), ac );
-    tenSecondsForward->setObjectName( "ten_seconds_forward" );
+    KAction* tenSecondsForward = new KAction( KIcon(QLatin1String( "media-seek-forward" )), i18n("Go 10 Seconds Forward"), ac );
+    tenSecondsForward->setObjectName( QLatin1String( "ten_seconds_forward" ) );
     tenSecondsForward->setShortcut( Qt::Key_Plus );
     connect( tenSecondsForward, SIGNAL( triggered() ), engine(), SLOT( tenSecondsForward() ) );
     addToAc( tenSecondsForward )
@@ -388,7 +386,7 @@ MainWindow::toggleVideoSettings( bool show )
     if( show )
     {
         m_leftDock = new QDockWidget( this );
-        m_leftDock->setObjectName("left_dock");
+        m_leftDock->setObjectName( QLatin1String("left_dock" ));
         m_leftDock->setFeatures( QDockWidget::NoDockWidgetFeatures );
         QWidget* videoSettingsWidget = new QWidget( m_leftDock );
         m_leftDock->setWidget( videoSettingsWidget );
@@ -401,7 +399,7 @@ MainWindow::toggleVideoSettings( bool show )
         updateSliders();
         foreach( QSlider* slider, m_sliders )
              connect( slider, SIGNAL( valueChanged( int ) ), engine(), SLOT( settingChanged( int ) ) );
-        
+
         connect( ui.defaultsButton, SIGNAL( clicked( bool ) ), this, SLOT( restoreDefaultVideoSettings() ) );
         connect( ui.closeButton, SIGNAL( clicked( bool ) ), action( "video_settings" ), SLOT( setChecked( bool ) ) );
         connect( ui.closeButton, SIGNAL( clicked( bool ) ), m_leftDock, SLOT( deleteLater() ) );
@@ -423,7 +421,6 @@ MainWindow::restoreDefaultVideoSettings()
 void
 MainWindow::toggleLoadView()
 {
-  DEBUG_BLOCK;
   if( engine()->state() == Phonon::PlayingState && TheStream::hasVideo() )
   {
     engine()->playPause();
@@ -440,13 +437,13 @@ MainWindow::toggleLoadView()
     }
     else if( m_currentWidget != m_audioView )
     {
-      debug() << "setting Thumbnail for video Widget";
+      kDebug() << "setting Thumbnail for video Widget";
       m_mainView->setCurrentWidget(m_loadView);
       m_mainView->removeWidget(m_currentWidget);
       engine()->isPreview(true);
       m_loadView->setThumbnail(m_currentWidget);
     }
-    else 
+    else
     {
       m_mainView->setCurrentWidget(m_loadView);
     }
@@ -505,29 +502,22 @@ MainWindow::updateSliders()
 void
 MainWindow::engineMessage( const QString &message )
 {
-    DEBUG_BLOCK
     statusBar()->showMessage( message, 3500 );
 }
 
 bool
 MainWindow::open( const KUrl &url )
 {
-    DEBUG_BLOCK
-    debug() << url;
+    kDebug() << url;
 
     if( load( url ) ) {
         const int offset = TheStream::hasProfile()
                 // adjust offset if we have session history for this video
                 ? TheStream::profile().readEntry<int>( "Position", 0 )
                 : 0;
-        debug() << "Initial offset is "<< offset;
+        kDebug() << "Initial offset is "<< offset;
         engine()->loadSettings();
         updateSliders();
-        if( TheStream::hasVideo() )
-          m_currentWidget = engine();
-        else
-          m_currentWidget = m_audioView;
-        m_mainView->setCurrentWidget(m_currentWidget);
         return engine()->play( offset );
     }
 
@@ -557,24 +547,33 @@ MainWindow::load( const KUrl &url )
         }
     }
 
-    if (url.protocol() == "media") {
+    // local protocols like nepomuksearch:/ are not supported by xine
+    // check if an UDS_LOCAL_PATH is defined.
+    if (KProtocolInfo::protocolClass(url.protocol()) == QLatin1String(":local")) {
         //#define UDS_LOCAL_PATH (72 | KIO::UDS_STRING)
         KIO::UDSEntry e;
-        if (!KIO::NetAccess::stat( url, e, 0 ))
-            MessageBox::sorry( i18n("There was an internal error with the media slave...") );
-        else {
+        if (KIO::NetAccess::stat( url, e, 0 )) {
             QString path = e.stringValue( KIO::UDSEntry::UDS_LOCAL_PATH );
             if( !path.isEmpty() )
                 return engine()->load( KUrl( path ) );
         }
     }
-    
+
     if( m_mainView->indexOf(engine()) == -1 )
       toggleLoadView();
 
     //let xine handle invalid, etc, KUrlS
     //TODO it handles non-existing files with bad error message
-    return engine()->load( url );
+    bool ret = engine()->load( url );
+    if( ret )
+    {
+        if( TheStream::hasVideo() )
+            m_currentWidget = engine();
+        else
+            m_currentWidget = m_audioView;
+        m_mainView->setCurrentWidget(m_currentWidget);
+    }
+    return ret;
 }
 
 void
@@ -595,7 +594,7 @@ MainWindow::play()
         else
           m_currentWidget = m_audioView;
         engine()->play();
-        m_mainView->setCurrentWidget(engine());
+        m_mainView->setCurrentWidget(m_currentWidget);
         break;
     default:
         break;
@@ -605,16 +604,17 @@ MainWindow::play()
 void
 MainWindow::openFileDialog()
 {
-       QStringList mimeFilter=Phonon::BackendCapabilities::availableMimeTypes();
+       QStringList mimeFilter = Phonon::BackendCapabilities::availableMimeTypes();
         //temporary fixes for MimeTypes that Xine does support but it doesn't return - this is a Xine bug.
-        mimeFilter << "audio/x-flac";
-        mimeFilter << "video/mp4";
-        mimeFilter << "application/x-cd-image"; // added for *.iso images
+        mimeFilter << QLatin1String( "audio/x-flac");
+        mimeFilter << QLatin1String( "video/mp4" );
+        mimeFilter << QLatin1String( "application/x-cd-image" ); // added for *.iso images
 
-        const KUrl url = KFileDialog::getOpenUrl( KUrl("kfiledialog:///dragonplayer"),mimeFilter.join(" "), this, i18n("Select File to Play") );
+        const KUrl url = KFileDialog::getOpenUrl( KUrl("kfiledialog:///dragonplayer"),mimeFilter.join(QLatin1String( " " ))
+                                        , this, i18n("Select File to Play") );
         if( url.isEmpty() )
         {
-            debug() << "URL empty in MainWindow::playDialogResult()";
+            kDebug() << "URL empty in MainWindow::playDialogResult()";
             return;
         }
         else
@@ -626,11 +626,10 @@ MainWindow::openFileDialog()
 void
 MainWindow::playDisc()
 {
-DEBUG_BLOCK
     QList< Solid::Device > playableDiscs;
     {
         QList< Solid::Device > deviceList = Solid::Device::listFromType( Solid::DeviceInterface::OpticalDisc );
-        
+
         foreach( const Solid::Device &device, deviceList )
         {
             const Solid::OpticalDisc* disc = device.as<const Solid::OpticalDisc>();
@@ -638,7 +637,7 @@ DEBUG_BLOCK
             {
                 if( disc->availableContent() & ( Solid::OpticalDisc::VideoDvd | Solid::OpticalDisc::VideoCd | Solid::OpticalDisc::SuperVideoCd |  Solid::OpticalDisc::Audio ) )
                     playableDiscs << device;
-            
+
             }
         }
     }
@@ -646,16 +645,20 @@ DEBUG_BLOCK
     {
         if( playableDiscs.size() > 1 ) //more than one disc, show user a selection box
         {
-            debug() << "> 1 possible discs, showing dialog";
+            kDebug() << "> 1 possible discs, showing dialog";
             new DiscSelectionDialog( this, playableDiscs );
         }
         else //only one optical disc inserted, play whatever it is
         {
-            debug() << "playing disc", engine()->playDisc( playableDiscs.first() );
+            bool status = engine()->playDisc( playableDiscs.first() );
+            kDebug() << "playing disc" << status ;
         }
     }
     else
-        engine()->playDvd(), debug() << "no disc in drive or Solid isn't working";
+    {
+        engine()->playDvd();
+        kDebug() << "no disc in drive or Solid isn't working";
+    }
 
 }
 
@@ -670,8 +673,7 @@ MainWindow::openRecentFile( const KUrl& url )
 void
 MainWindow::setFullScreen( bool isFullScreen )
 {
-    DEBUG_BLOCK
-    debug() << "Setting full screen to " << isFullScreen;
+    kDebug() << "Setting full screen to " << isFullScreen;
     mainWindow()->setWindowState( (isFullScreen ? Qt::WindowFullScreen : Qt::WindowNoState ));
     static FullScreenToolBarHandler *s_handler;
 
@@ -712,12 +714,11 @@ MainWindow::showVolume( bool visible)
 void
 MainWindow::aboutToShowMenu()
 {
-    DEBUG_BLOCK
     TheStream::aspectRatioAction()->setChecked( true );
     {
         int subId = TheStream::subtitleChannel();
         QList< QAction* > subs = action("subtitle_channels_menu")->menu()->actions();
-        debug() << "subtitle #" << subId << " is going to be checked";
+        kDebug() << "subtitle #" << subId << " is going to be checked";
         foreach( QAction* subAction, subs )
         {
             if( subAction->property( TheStream::CHANNEL_PROPERTY ).toInt() == subId )
@@ -725,13 +726,13 @@ MainWindow::aboutToShowMenu()
                 subAction->setChecked( true );
                 break;
             }
-            debug() << subAction->property( TheStream::CHANNEL_PROPERTY ).toInt() << " not checked.";
+            kDebug() << subAction->property( TheStream::CHANNEL_PROPERTY ).toInt() << " not checked.";
         }
     }
     {
         int audioId = TheStream::audioChannel();
         QList< QAction* > audios = action("audio_channels_menu")->menu()->actions();
-        debug() << "audio #" << audioId << " is going to be checked";
+        kDebug() << "audio #" << audioId << " is going to be checked";
         foreach( QAction* audioAction, audios )
         {
             if( audioAction->property( TheStream::CHANNEL_PROPERTY ).toInt() == audioId )
@@ -778,13 +779,13 @@ QMenu*
 MainWindow::menu( const char *name )
 {
     // KXMLGUI is "really good".
-    return static_cast<QMenu*>(factory()->container( name, this ));
+    return static_cast<QMenu*>(factory()->container( QLatin1String( name ), this ));
 }
 
-void 
+void
 MainWindow::streamSettingChange()
 {
-    if( sender()->objectName().left( 5 ) == "ratio" )
+    if( sender()->objectName().left( 5 ) == QLatin1String( "ratio" ) )
     {
         TheStream::setRatio( dynamic_cast< QAction* > ( sender() ) );
     }
@@ -805,14 +806,13 @@ MainWindow::updateTitleBarText()
     {
         m_titleLabel->setText( TheStream::prettyTitle() );
     }
-    debug() << "set titles ";
+    kDebug() << "set titles ";
 }
 
 #define CHANNELS_CHANGED( function, actionName ) \
 void \
 MainWindow::function( QList< QAction* > subActions ) \
 { \
-DEBUG_BLOCK \
     if( subActions.size() <= 2 ) \
           action( actionName )->setEnabled( false ); \
     else \
@@ -842,9 +842,9 @@ action( const char *name )
 
     if( mainWindow() )
         if( ( actionCollection = ((MainWindow*)mainWindow() )->actionCollection() ) )
-            action = actionCollection->action( name );
+            action = actionCollection->action(QLatin1String( name ) );
     if( !action )
-        debug() << name;
+        kDebug() << name;
     Q_ASSERT( mainWindow() );
     Q_ASSERT( actionCollection );
     Q_ASSERT( action );
