@@ -7,7 +7,7 @@
  * published by the Free Software Foundation; either version 2 of
  * the License or (at your option) version 3 or any later version
  * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy 
+ * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
  *
  * This program is distributed in the hope that it will be useful,
@@ -118,25 +118,23 @@ namespace Dragon
 
       QPointer<QDockWidget> m_leftDock;
       QPointer<QDockWidget> m_rightDock;
-      QWidget     *m_positionSlider;
+      QWidget *m_positionSlider;
       QPointer<QWidget> m_volumeSlider;
       QCheckBox *m_muteCheckBox;
-      TimeLabel   *m_timeLabel;
-      QLabel      *m_titleLabel;
+      TimeLabel *m_timeLabel;
+      QLabel *m_titleLabel;
       QList<QSlider*> m_sliders;
       QPointer<PlayDialog> m_playDialog;
 
       KNotificationRestrictions *m_stopScreenSaver;
-	  int m_screensaverDisableCookie;
+      int m_screensaverDisableCookie;
       int m_stopSleepCookie;
 
       bool m_toolbarIsHidden;
       bool m_statusbarIsHidden;
 
       QActionGroup *m_aspectRatios;
-      //undefined
-      MainWindow( const MainWindow& );
-      MainWindow &operator=( const MainWindow& );
+      Q_DISABLE_COPY(MainWindow)
 
    protected:
       void closeEvent( QCloseEvent * event );
