@@ -29,7 +29,7 @@
 extern "C"
 {
 	//cdda_interface.h in cdparanoia 10.2 has a member called 'private' which the C++ compiler doesn't like
-	#define private _private   
+	#define private _private
 	#include <cdda_interface.h>
 	#include <cdda_paranoia.h>
 	#undef private
@@ -62,7 +62,7 @@ extern "C"
 
 using namespace KIO;
 
-#define CDDB_INFORMATION "CDDB Information"
+#define CDDB_INFORMATION I18N_NOOP("CDDB Information")
 
 using namespace AudioCD;
 
@@ -98,16 +98,15 @@ enum Which_dir {
 	Info, // CDDB info
 	Root, // The root directory, shows all these :)
 	FullCD, // Show a single file containing all of the data
-	EncoderDir // A directory created by an encoder
+	EncoderDir, // The root directory created by an encoder
+	SubDir // A directory created from the Album name configuration
 };
 
 class AudioCDProtocol::Private {
 public:
-	Private() : cd(KCompactDisc::Asynchronous) {
+	Private() : s_info(i18n("Information")), s_fullCD(i18n("Full CD"))
+	{
 		clearURLargs();
-		s_info = i18n("Information");
-		s_fullCD = i18n("Full CD");
-		discid = 0;
 	}
 
 	void clearURLargs() {
@@ -117,11 +116,34 @@ public:
 		cddbUserChoice = -1;
 	}
 
+	bool tocsAreDifferent(struct cdrom_drive *drive)
+	{
+		if (tracks != (uint)drive->tracks) return true;
+		for (int i = 0; i < drive->tracks; ++i)
+		{
+			if (disc_toc[i].dwStartSector != drive->disc_toc[i].dwStartSector ||
+			    disc_toc[i].bFlags != drive->disc_toc[i].bFlags ||
+			    disc_toc[i].bTrack != drive->disc_toc[i].bTrack) return true;
+		}
+		return false;
+	}
+
+	void setToc(struct cdrom_drive *drive)
+	{
+		for (int i = 0; i < drive->tracks; ++i)
+		{
+			disc_toc[i].dwStartSector = drive->disc_toc[i].dwStartSector;
+			disc_toc[i].bFlags = drive->disc_toc[i].bFlags;
+			disc_toc[i].bTrack = drive->disc_toc[i].bTrack;
+		}
+	}
+
 	// The type/which of request
 	bool req_allTracks;
 	Which_dir which_dir;
 	int req_track;
 	QString fname;
+	QString child_dir;
 	AudioCDEncoder *encoder_dir_type;
 
 	// Misc settings
@@ -130,14 +152,13 @@ public:
 	bool reportErrors;
 
 	// Directory strings, never change after init
-	QString s_info;
-	QString s_fullCD;
+	const QString s_info;
+	const QString s_fullCD;
 
 	// Current CD
-	unsigned discid;
+	TOC disc_toc[MAXTRK];
 	unsigned tracks;
 	bool trackIsAudio[100];
-	KCompactDisc cd; // keep it around so that we don't assume the disk changed between every stat()
 
 	// CDDB items
 	KCDDB::Result cddbResult;
@@ -147,13 +168,15 @@ public:
 
 	// Template for ..
 	QString fileNameTemplate; // URL settable
-	QString albumTemplate; // URL settable
+	QString albumNameTemplate; // URL settable
+	QString fileLocationTemplate;  // URL settable
 	QString rsearch;
 	QString rreplace;
 
 	// Current strings for this CD and or cddb selection
 	QStringList templateTitles;
 	QString templateAlbumName;
+	QString templateFileLocation;
 };
 
 int paranoia_read_limited_error;
@@ -165,8 +188,8 @@ AudioCDProtocol::AudioCDProtocol(const QByteArray & protocol, const QByteArray &
 
 	// Add encoders
 	AudioCDEncoder::findAllPlugins(this, encoders);
-	encoderTypeCDA = encoderFromExtension(".cda");
-	encoderTypeWAV = encoderFromExtension(".wav");
+	encoderTypeCDA = encoderFromExtension(QLatin1String( ".cda" ));
+	encoderTypeWAV = encoderFromExtension(QLatin1String( ".wav" ));
 }
 
 AudioCDProtocol::~AudioCDProtocol()
@@ -181,7 +204,7 @@ AudioCDEncoder *AudioCDProtocol::encoderFromExtension(const QString& extension)
 	AudioCDEncoder *encoder;
 	for (int i = encoders.size()-1; i >= 0; --i) {
             encoder = encoders.at(i);
-	    if(QString(".")+encoder->fileType() == extension)
+	    if(QLatin1String(".")+QLatin1String( encoder->fileType() ) == extension)
 	        return encoder;
     	}
 	Q_ASSERT(false);
@@ -191,10 +214,56 @@ AudioCDEncoder *AudioCDProtocol::encoderFromExtension(const QString& extension)
 AudioCDEncoder *AudioCDProtocol::determineEncoder(const QString & filename)
 {
 	int len = filename.length();
-	int pos = filename.lastIndexOf('.');
+	int pos = filename.lastIndexOf( QLatin1Char( '.' ));
 	return encoderFromExtension(filename.right(len - pos));
 }
 
+static void setDeviceToCd(KCompactDisc *cd, struct cdrom_drive *drive)
+{
+#if defined(HAVE_CDDA_IOCTL_DEVICE)
+	cd->setDevice(QLatin1String( drive->ioctl_device_name ), 50, false);
+#elif defined(__FreeBSD__) || defined(__DragonFly__)
+	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
+	// support for non-SCSI devices. Although it finds ATA cdroms just
+	// fine, there is no straightforward way to discover the device
+	// name associated with the device, which throws the rest of audiocd
+	// for a loop.
+	//
+	if ( !(drive->dev) || (COOKED_IOCTL == drive->interface) )
+	{
+		// For ATAPI devices, we have no real choice. Use the
+		// user selected value, even if there is none.
+		//
+		kWarning(7117) << "Found an ATAPI device, assuming it is the one specified by the user.";
+		cd->setDevice( drive->cdda_device_name );
+	}
+	else
+	{
+		kDebug(7117) << "Found a SCSI or ATAPICAM device.";
+		if ( strlen(drive->dev->device_path) > 0 )
+		{
+			cd->setDevice( drive->dev->device_path );
+		}
+		else
+		{
+			// But the device_path can be empty under some
+			// circumstances, so build a representation from
+			// the unit number and SCSI device name.
+			//
+			QString devname = QString::fromLatin1( "/dev/%1%2" )
+				.arg( drive->dev->given_dev_name )
+				.arg( drive->dev->given_unit_number ) ;
+			kDebug(7117) << "  Using derived name " << devname;
+			cd->setDevice( devname );
+		}
+	}
+#else
+#ifdef __GNUC__
+	#warning audiocd ioslave is not going to work for you
+#endif
+#endif
+}
+
 struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 {
 	if (url.hasHost())
@@ -214,60 +283,19 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 	if (0 == drive)
 		return 0;
 
-	// Update our knowledge of the disc
-#if defined(HAVE_CDDA_IOCTL_DEVICE)
-	if (d->cd.deviceName() != drive->ioctl_device_name)
-		d->cd.setDevice(drive->ioctl_device_name, 50, false);
-#elif defined(__FreeBSD__) || defined(__DragonFly__)
-	// FreeBSD's cdparanoia as of january 5th 2006 has rather broken
-	// support for non-SCSI devices. Although it finds ATA cdroms just
-	// fine, there is no straightforward way to discover the device
-	// name associated with the device, which throws the rest of audiocd
-	// for a loop.
-	//
-	if ( !(drive->dev) || (COOKED_IOCTL == drive->interface) )
+	if (d->tocsAreDifferent(drive))
 	{
-		// For ATAPI devices, we have no real choice. Use the
-		// user selected value, even if there is none.
-		//
-		kWarning(7117) << "Found an ATAPI device, assuming it is the one specified by the user.";
-		d->cd.setDevice( d->device );
-	}
-	else
-	{
-		kDebug(7117) << "Found a SCSI or ATAPICAM device.";
-		if ( strlen(drive->dev->device_path) > 0 )
-		{
-			d->cd.setDevice( drive->dev->device_path );
-		}
-		else
-		{
-			// But the device_path can be empty under some
-			// circumstances, so build a representation from
-			// the unit number and SCSI device name.
-			//
-			QString devname = QString::fromLatin1( "/dev/%1%2" )
-				.arg( drive->dev->given_dev_name )
-				.arg( drive->dev->given_unit_number ) ;
-			kDebug(7117) << "  Using derived name " << devname;
-			d->cd.setDevice( devname );
-		}
-	}
-#else
-#ifdef __GNUC__
-	#warning audiocd ioslave is not going to work for you
-#endif
-#endif
+		// Update our knowledge of the disc
+		KCompactDisc cd(KCompactDisc::Asynchronous);
+		setDeviceToCd(&cd, drive);
+		d->setToc(drive);
 
-
-	if (d->cd.discId() != d->discid && !d->cd.isNoDisc()) {
-		d->discid = d->cd.discId();
-		d->tracks = d->cd.tracks();
-		for(uint i=0; i< d->cd.tracks(); i++)
-			d->trackIsAudio[i] = d->cd.isAudio(i+1);
+		d->tracks = cd.tracks();
+		for(uint i=0; i< cd.tracks(); i++)
+			d->trackIsAudio[i] = cd.isAudio(i+1);
 
 		KCDDB::Client c;
-		d->cddbResult = c.lookup(d->cd.discSignature());
+		d->cddbResult = c.lookup(cd.discSignature());
 		if (d->cddbResult == Success)
 		{
 			d->cddbList = c.lookupResponse();
@@ -277,53 +305,77 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 	}
 
 	// Determine what file or folder that is wanted.
-	d->fname = url.fileName(KUrl::ObeyTrailingSlash);
-	QString dname = url.directory(KUrl::AppendTrailingSlash);
-	if (!dname.isEmpty() && dname[0] == '/')
-		dname = dname.mid(1);
+	QString path = url.path();
+	if (!path.isEmpty() && path[0] == QLatin1Char( '/' ))
+		path = path.mid(1);
 
-	// Kong issue where they send dirs as files, double check
-	/* A hack, for when konqi wants to list the directory audiocd:/Bla
-		 it really submits this URL, instead of audiocd:/Bla/ to us. We could
-		 send (in listDir) the UDSEntry::UDS_NAME as "Bla/" for directories, but then
-		 konqi shows them as "Bla//" in the status line. */
-	// See if it is an encoder directory
-	AudioCDEncoder *encoder;
-	for (int i = encoders.size()-1; i >= 0; --i) {
-            encoder = encoders.at(i);
-	    if(encoder->type() == d->fname){
-		dname = d->fname;
-		d->fname = "";
-		break;
-	    }
-	}
-	// Other Hard coded directories
-	if (dname.isEmpty() && (d->fname == d->s_info || d->fname == d->s_fullCD ))
-	{
-		dname = d->fname;
-		d->fname = "";
-	}
-	// end hack
+	d->req_allTracks = false;
 
-
-	// See which directory they want
+	// See which file and directory they want
+	QString remainingDirPath;
 	d->which_dir = Unknown;
-	for (int i = encoders.size()-1; i >= 0; --i) {
-            encoder = encoders.at(i);
-		if(encoder->type() == dname){
-			d->which_dir = EncoderDir;
-			d->encoder_dir_type = encoder;
-			break;
+	if (path.isEmpty()) {
+		d->which_dir = Root;
+		d->encoder_dir_type = encoderTypeWAV;
+		remainingDirPath = d->templateFileLocation;
+		d->fname = QString();
+	} else {
+		for (int i = encoders.size()-1; i >= 0; --i) {
+			AudioCDEncoder *encoder = encoders.at(i);
+			QString encoderFileLocation = encoder->type();
+		        if (!d->templateFileLocation.isEmpty())	encoderFileLocation = encoderFileLocation + QLatin1String( "/" ) + d->templateFileLocation;
+			if (path == encoder->type()) {
+				d->which_dir = EncoderDir;
+				d->encoder_dir_type = encoder;
+				remainingDirPath = encoderFileLocation.mid(path.length());
+				d->fname = QString();
+				break;
+			} else if (encoderFileLocation.startsWith(path)) {
+				d->which_dir = SubDir;
+				d->encoder_dir_type = encoder;
+				remainingDirPath = encoderFileLocation.mid(path.length());
+				d->fname = QString();
+				break;
+			} else if (path.startsWith(encoderFileLocation)) {
+				d->which_dir = SubDir;
+				d->encoder_dir_type = encoder;
+				remainingDirPath = QString();
+				d->fname = path.mid(encoderFileLocation.length() + 1);
+				break;
+			} else if (path.startsWith(encoder->type())) {
+				d->which_dir = EncoderDir;
+				d->encoder_dir_type = encoder;
+				remainingDirPath = QString();
+				d->fname = path.mid(encoder->type().length() + 1);
+			}
+		}
+		if ( Unknown == d->which_dir ) {
+			if (path.startsWith(d->s_info)) {
+				d->which_dir = Info;
+				d->fname = path.mid(d->s_info.length() + 1);
+			} else if (path.startsWith(d->s_fullCD)) {
+				d->which_dir = FullCD;
+				d->fname = path.mid(d->s_fullCD.length() + 1);
+				d->req_allTracks = true;
+			} else if (d->templateFileLocation.startsWith(path)) {
+				d->which_dir = SubDir;
+				d->encoder_dir_type = encoderTypeWAV;
+				remainingDirPath = d->templateFileLocation.mid(path.length());
+				d->fname = QString();
+			} else if (path.startsWith(d->templateFileLocation)) {
+				d->encoder_dir_type = encoderTypeWAV;
+				remainingDirPath = QString();
+				d->fname = path.mid(d->templateFileLocation.length() + 1);
+			} else  {
+				d->encoder_dir_type = encoderTypeWAV;
+				remainingDirPath = QString();
+				d->fname = path;
+			}
 		}
 	}
-	if ( Unknown == d->which_dir ){
-		if (dname.isEmpty())
-			d->which_dir = Root;
-		else if (dname == d->s_info)
-			d->which_dir = Info;
-		else if (dname == d->s_fullCD)
-			d->which_dir = FullCD;
-	}
+	if (!remainingDirPath.isEmpty() && remainingDirPath[0] == QLatin1Char( '/' ))
+		remainingDirPath = remainingDirPath.mid(1);
+	d->child_dir = remainingDirPath.split(QLatin1String( "/" )).first();
 
 	// See if the url is a track
 	d->req_track = -1;
@@ -331,7 +383,7 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 		QString name(d->fname);
 
 		// Remove extension
-		int dot = name.lastIndexOf('.');
+		int dot = name.lastIndexOf( QLatin1Char( '.' ));
 		if (dot >= 0)
 			name.truncate(dot);
 
@@ -369,10 +421,7 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const KUrl & url)
 	if (d->req_track >= (int)d->tracks)
 		d->req_track = -1;
 
-	// Are we in the directory that lists "full CD" files?
-	d->req_allTracks = (dname.contains(d->s_fullCD));
-
-	kDebug(7117) << "dir=" << dname << " file=" << d->fname
+	kDebug(7117) << "path=" << path << " file=" << d->fname
 		<< " req_track=" << d->req_track << " which_dir=" << d->which_dir << " full CD?=" << d->req_allTracks << endl;
 	return drive;
 }
@@ -404,15 +453,15 @@ void AudioCDProtocol::get(const KUrl & url)
 
 	if( d->fname.contains(i18n(CDDB_INFORMATION))){
 		uint choice = 1;
-		if(d->fname != QString("%1.txt").arg(i18n(CDDB_INFORMATION))){
-			choice= d->fname.section('_',1,1).section('.',0,0).toInt();
+		if(d->fname != QString::fromLatin1("%1.txt").arg(i18n(CDDB_INFORMATION))){
+			choice= d->fname.section(QLatin1Char( '_' ),1,1).section(QLatin1Char( '.' ),0,0).toInt();
 		}
 		uint count = 1;
 		CDInfoList::iterator it;
 		bool found = false;
 		for ( it = d->cddbList.begin(); it != d->cddbList.end(); ++it ){
 			if(count == choice){
-				mimeType("text/html");
+				mimeType(QLatin1String( "text/html" ));
 				data(QByteArray( (*it).toString().toLatin1() ));
 				// send an empty QByteArray to signal end of data.
 				data(QByteArray());
@@ -422,8 +471,8 @@ void AudioCDProtocol::get(const KUrl & url)
 			}
 			count++;
 		}
-		if(!found && d->fname.contains(i18n(CDDB_INFORMATION)+':')){
-			mimeType("text/html");
+		if(!found && d->fname.contains(i18n(CDDB_INFORMATION)+QLatin1Char( ':' ))){
+			mimeType(QLatin1String( "text/html" ));
 			//data(QCString( d->fname.latin1() ));
 			// send an empty QByteArray to signal end of data.
 			data(QByteArray());
@@ -456,7 +505,6 @@ void AudioCDProtocol::get(const KUrl & url)
 
 		int track = d->req_track+1;
 
-		QString trackName;
 		// hack
 		// do we rip the whole CD?
 		if (d->req_allTracks){
@@ -464,7 +512,7 @@ void AudioCDProtocol::get(const KUrl & url)
 			// YES => the title of the file is the title of the CD
 			info.track(track-1).set(Title, info.get(Title));
 		}
-		encoder->fillSongInfo(info, track, "");
+		encoder->fillSongInfo(info, track, QString());
 	}
 	long totalByteCount = CD_FRAMESIZE_RAW * (lastSector - firstSector + 1);
 	long time_secs = (8 * totalByteCount) / (44100 * 2 * 16);
@@ -490,11 +538,11 @@ void AudioCDProtocol::stat(const KUrl & url)
 	if (!drive)
 		return;
 
-	bool isFile = !d->fname.isEmpty();
+	const bool isFile = !d->fname.isEmpty();
 
 	// the track number. 0 if ripping
 	// the whole CD.
-	uint trackNumber = d->req_track + 1;
+	const uint trackNumber = d->req_track + 1;
 
 	if (!d->req_allTracks)
 	{ // we only want to rip one track.
@@ -508,7 +556,7 @@ void AudioCDProtocol::stat(const KUrl & url)
 
 	UDSEntry entry;
 
-	entry.insert( KIO::UDSEntry::UDS_NAME, url.fileName().replace('/', QLatin1String("%2F") ));
+	entry.insert( KIO::UDSEntry::UDS_NAME, url.fileName().replace(QLatin1Char( '/' ), QLatin1String("%2F") ));
 
 	entry.insert( KIO::UDSEntry::UDS_FILE_TYPE,isFile ? S_IFREG : S_IFDIR);
 
@@ -545,7 +593,7 @@ static void app_dir(UDSEntry& e, const QString & n, size_t s)
 	e.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
 	e.insert( KIO::UDSEntry::UDS_ACCESS, 0400);
 	e.insert( KIO::UDSEntry::UDS_SIZE, s);
-	e.insert( KIO::UDSEntry::UDS_MIME_TYPE, QString("inode/directory"));
+	e.insert( KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String("inode/directory"));
 }
 
 static void app_file(UDSEntry& e, const QString & n, size_t s, const QString &mimetype = QString())
@@ -584,8 +632,6 @@ void AudioCDProtocol::listDir(const KUrl & url)
 	generateTemplateTitles();
 
 	UDSEntry entry;
-	// If the tracks should be listed in this directory
-	bool list_tracks = true;
 
 	if (d->which_dir == Info){
 		CDInfoList::iterator it;
@@ -593,20 +639,18 @@ void AudioCDProtocol::listDir(const KUrl & url)
 		for ( it = d->cddbList.begin(); it != d->cddbList.end(); ++it ){
 			(*it).toString();
 			if(count == 1)
-				app_file(entry, QString("%1.txt").arg(i18n(CDDB_INFORMATION)), ((*it).toString().length())+1);
+                            app_file(entry, QString::fromLatin1("%1.txt").arg(i18n(CDDB_INFORMATION)), ((*it).toString().length())+1);
 			else
-				app_file(entry, QString("%1_%2.txt").arg(i18n(CDDB_INFORMATION)).arg(count), ((*it).toString().length())+1);
+                            app_file(entry, QString::fromLatin1("%1_%2.txt").arg(i18n(CDDB_INFORMATION)).arg(count), ((*it).toString().length())+1);
 			count++;
 			listEntry(entry, false);
 		}
 		// Error
 		if( count == 1 ) {
-			app_file(entry, QString("%1: %2.txt").arg(i18n(CDDB_INFORMATION)).arg(KCDDB::resultToString(d->cddbResult)), ((*it).toString().length())+1);
+                    app_file(entry, QString::fromLatin1("%1: %2.txt").arg(i18n(CDDB_INFORMATION)).arg(KCDDB::resultToString(d->cddbResult)), 0);
 			count++;
 			listEntry(entry, false);
 		}
-
-		list_tracks = false;
 	}
 
 	if (d->which_dir == Root){
@@ -631,46 +675,49 @@ void AudioCDProtocol::listDir(const KUrl & url)
 	}
 
 	// Now fill in the tracks for the current directory
-	if (list_tracks && d->which_dir == FullCD) {
-		// if we're listing the "full CD" subdirectory :
-		if ( (d->which_dir == FullCD) ) {
-			AudioCDEncoder *encoder;
-			for (int i = encoders.size()-1; i >= 0; --i) {
-            			encoder = encoders.at(i);
-				if (d->cddbResult != KCDDB::Success)
-					addEntry(d->s_fullCD, encoder, drive, -1);
-				else
-					addEntry(d->templateAlbumName, encoder, drive, -1);
-			}
+	if (d->which_dir == FullCD) {
+		AudioCDEncoder *encoder;
+		for (int i = encoders.size()-1; i >= 0; --i) {
+			encoder = encoders.at(i);
+			if (d->cddbResult != KCDDB::Success)
+				addEntry(d->s_fullCD, encoder, drive, -1);
+			else
+				addEntry(d->templateAlbumName, encoder, drive, -1);
 		}
 	}
 
-	if (list_tracks && d->which_dir != FullCD) {
-		// listing another dir than the "FullCD" one.
-		for (uint trackNumber = 1; trackNumber <= d->tracks; trackNumber++)
+	if (d->which_dir == SubDir || d->which_dir == Root || d->which_dir == EncoderDir) {
+		if (d->child_dir.isEmpty() || d->which_dir == Root || d->which_dir == EncoderDir)
 		{
-			// Skip data tracks
-			if (!d->trackIsAudio[trackNumber-1])
-				continue;
+			// we are at the end of the hierarchy, list the tracks
+			for (uint trackNumber = 1; trackNumber <= d->tracks; trackNumber++)
+			{
+				// Skip data tracks
+				if (!d->trackIsAudio[trackNumber-1])
+					continue;
 
-			switch (d->which_dir) {
-				case Root:{
-					addEntry(d->templateTitles[trackNumber - 1],
-						encoderTypeWAV, drive, trackNumber);
-					break;
+				switch (d->which_dir) {
+					case EncoderDir:
+					case SubDir:
+					case Root:
+						addEntry(d->templateTitles[trackNumber - 1],
+							d->encoder_dir_type, drive, trackNumber);
+						break;
+					case Info:
+					case Unknown:
+					default:
+						error(KIO::ERR_INTERNAL, url.path());
+						cdda_close(drive);
+						return;
 				}
-				case EncoderDir:
-					addEntry(d->templateTitles[trackNumber - 1],
-						d->encoder_dir_type, drive, trackNumber);
-					break;
-				case Info:
-				case Unknown:
-				default:
-					error(KIO::ERR_INTERNAL, url.path());
-					cdda_close(drive);
-					return;
 			}
 		}
+
+		if (!d->child_dir.isEmpty())
+		{
+			app_dir(entry, d->child_dir, 1);
+			listEntry(entry, false);
+		}
 	}
 
 	totalSize(entry.count());
@@ -698,7 +745,7 @@ void AudioCDProtocol::addEntry(const QString& trackTitle, AudioCDEncoder *encode
 		theFileSize = fileSize(firstSector, lastSector, encoder);
 	}
 	UDSEntry entry;
-	app_file(entry, trackTitle + QString(".")+encoder->fileType(), theFileSize, encoder->mimeType());
+	app_file(entry, trackTitle + QLatin1String(".")+QLatin1String( encoder->fileType() ), theFileSize, QLatin1String( encoder->mimeType() ));
 	listEntry(entry, false);
 }
 
@@ -715,11 +762,11 @@ long AudioCDProtocol::fileSize(long firstSector, long lastSector, AudioCDEncoder
 
 struct cdrom_drive *AudioCDProtocol::getDrive()
 {
-	QByteArray device(QFile::encodeName(d->device));
+	const QByteArray device(QFile::encodeName(d->device));
 
 	struct cdrom_drive * drive = 0;
 
-	if (!device.isEmpty() && device != "/")
+	if (!device.isEmpty() && device != "/" )
 		drive = cdda_identify(device, CDDA_MESSAGE_PRINTIT, 0);
 	else
 	{
@@ -735,7 +782,7 @@ struct cdrom_drive *AudioCDProtocol::getDrive()
 	if (0 == drive) {
 		kDebug(7117) << "Can't find an audio CD on: \"" << d->device << "\"";
 
-		QFileInfo fi(d->device);
+		const QFileInfo fi(d->device);
 		if(!fi.isReadable())
 			error(KIO::ERR_SLAVE_DEFINED, i18n("Device does not have read permissions for this account.  Check the read permissions on the device."));
 		else if(!fi.isWritable())
@@ -836,7 +883,7 @@ void AudioCDProtocol::paranoiaRead(
 			QString errMsg = i18n( "Could not read %1: encoding failed", fileName );
 			QString details = encoder->lastErrorMessage();
 			if ( !details.isEmpty() )
-			    errMsg += '\n' + details;
+			    errMsg += QLatin1Char( '\n' ) + details;
 			error( ERR_SLAVE_DEFINED, errMsg );
 			break;
 		}
@@ -927,23 +974,23 @@ void AudioCDProtocol::parseURLArgs(const KUrl & url)
 
 	QString query(QUrl::fromPercentEncoding(url.query().toAscii()));
 
-	if (query.isEmpty() || query[0] != '?')
+	if (query.isEmpty() || query[0] != QLatin1Char( '?' ))
 		return;
 
 	query = query.mid(1); // Strip leading '?'.
 
-	QStringList tokens(query.split('&',QString::SkipEmptyParts));
+	const QStringList tokens(query.split(QLatin1Char( '&' ),QString::SkipEmptyParts));
 
 	for (QStringList::ConstIterator it(tokens.constBegin()); it != tokens.constEnd(); ++it)
 	{
-		QString token(*it);
+		const QString token(*it);
 
-		int equalsPos = token.indexOf('=');
+		int equalsPos = token.indexOf(QLatin1Char( '=' ));
 		if (-1 == equalsPos)
 			continue;
 
-		QString attribute(token.left(equalsPos));
-		QString value(token.mid(equalsPos + 1));
+		const QString attribute(token.left(equalsPos));
+		const QString value(token.mid(equalsPos + 1));
 
 		if (attribute == QLatin1String("device"))
 			d->device = value;
@@ -952,7 +999,9 @@ void AudioCDProtocol::parseURLArgs(const KUrl & url)
 		else if (attribute == QLatin1String("fileNameTemplate"))
 			d->fileNameTemplate = value;
 		else if (attribute == QLatin1String("albumNameTemplate"))
-			d->albumTemplate = value;
+			d->albumNameTemplate = value;
+		else if (attribute == QLatin1String("fileLocationTemplate"))
+			d->fileLocationTemplate = value;
 		else if (attribute == QLatin1String("cddbChoice"))
 			d->cddbUserChoice = value.toInt();
 		else if (attribute == QLatin1String("niceLevel")){
@@ -969,8 +1018,8 @@ void AudioCDProtocol::parseURLArgs(const KUrl & url)
  */
 void AudioCDProtocol::loadSettings()
 {
-	KConfig *config = new KConfig(QLatin1String( "kcmaudiocdrc"), KConfig::NoGlobals );
-        KConfigGroup groupCDDA( config, "CDDA" );
+	const KConfig *config = new KConfig(QLatin1String( "kcmaudiocdrc"), KConfig::NoGlobals );
+        const KConfigGroup groupCDDA( config, "CDDA" );
 
 	if (!groupCDDA.readEntry("autosearch", true)) {
 		d->device = groupCDDA.readEntry("device", QString(KCompactDisc::defaultCdromDeviceUrl().url()));
@@ -996,16 +1045,20 @@ void AudioCDProtocol::loadSettings()
 	}
 
 	// The default track filename template
-        KConfigGroup groupFileName( config, "FileName" );
+	const KConfigGroup groupFileName( config, "FileName" );
 	d->fileNameTemplate = groupFileName.readEntry("file_name_template", "%{trackartist} - %{number} - %{title}");
-	d->albumTemplate = groupFileName.readEntry("album_template", "%{albumartist} - %{albumtitle}");
+	d->albumNameTemplate = groupFileName.readEntry("album_name_template", "%{albumartist} - %{albumtitle}");
+	if (groupFileName.readEntry("show_file_location", false))
+		d->fileLocationTemplate = groupFileName.readEntry("file_location_template", QString());
+	else
+		d->fileLocationTemplate = QString();
 	d->rsearch = groupFileName.readEntry("regexp_search");
 	d->rreplace = groupFileName.readEntry("regexp_replace");
 	// if the regular expressions are enclosed in qoutes. remove them
 	// otherwise it is not possible to search for a space " ", since an empty (only spaces) value is not
 	// supported by KConfig, so the space has to be qouted, but then here the regexp searches really for " "
 	// instead of just the space. Alex
-	QRegExp qoutedString("^\".*\"$");
+	QRegExp qoutedString( QLatin1String( "^\".*\"$" ));
 	if (qoutedString.exactMatch(d->rsearch))
 	{
 		d->rsearch=d->rsearch.mid(1, d->rsearch.length()-2);
@@ -1051,32 +1104,34 @@ void AudioCDProtocol::generateTemplateTitles()
 	d->templateTitles.clear();
 	for (uint i = 0; i < d->tracks; i++) {
 		QHash<QString, QString> macros;
-		macros["albumartist"] = info.get(Artist).toString();
-		macros["albumtitle"] = info.get(Title).toString();
-		macros["title"] = info.track(i).get(Title).toString();
-		macros["trackartist"] = info.track(i).get(Artist).toString();
+		macros[QLatin1String( "albumartist" )] = info.get(Artist).toString();
+		macros[QLatin1String( "albumtitle" )] = info.get(Title).toString();
+		macros[QLatin1String( "title" )] = info.track(i).get(Title).toString();
+		macros[QLatin1String( "trackartist" )] = info.track(i).get(Artist).toString();
 		QString n;
-		macros["number"] = n.sprintf("%02d", i + 1);
+		macros[QLatin1String( "number" )] = n.sprintf("%02d", i + 1);
 		//macros["number"] = QString("%1").arg(i+1, 2, 10);
-		macros["genre"] = info.get(Genre).toString();
-		macros["year"] = info.get(Year).toString();
+		macros[QLatin1String( "genre" )] = info.get(Genre).toString();
+		macros[QLatin1String( "year" )] = info.get(Year).toString();
 
-		QString title = KMacroExpander::expandMacros(d->fileNameTemplate, macros, '%').replace('/', QLatin1String("%2F"));
+		QString title = KMacroExpander::expandMacros(d->fileNameTemplate, macros, QLatin1Char( '%' )).replace(QLatin1Char( '/' ), QLatin1String("%2F"));
 		title.replace( QRegExp(d->rsearch), d->rreplace );
 		d->templateTitles.append(title);
 	}
 
 	QHash<QString, QString> macros;
-	macros["albumartist"] = info.get(Artist).toString();
-	macros["albumtitle"] = info.get(Title).toString();
-	macros["genre"] = info.get(Genre).toString();
-	macros["year"] = info.get(Year).toString();
-	d->templateAlbumName = KMacroExpander::expandMacros(d->albumTemplate, macros, '%').replace('/', QLatin1String("%2F"));
+	macros[QLatin1String( "albumartist" )] = info.get(Artist).toString();
+	macros[QLatin1String( "albumtitle" )] = info.get(Title).toString();
+	macros[QLatin1String( "genre" )] = info.get(Genre).toString();
+	macros[QLatin1String( "year" )] = info.get(Year).toString();
+	d->templateAlbumName = KMacroExpander::expandMacros(d->albumNameTemplate, macros, QLatin1Char( '%' )).replace(QLatin1Char( '/' ), QLatin1String("%2F"));
 	d->templateAlbumName.replace( QRegExp(d->rsearch), d->rreplace );
+
+	d->templateFileLocation = KMacroExpander::expandMacros(d->fileLocationTemplate, macros, QLatin1Char( '%' ));
 }
 
 /**
- * Based upon the cdparinoia ripping application
+ * Based upon the cdparanoia ripping application
  * Only output BAD stuff
  * The higher the paranoia_read_limited_error the worse the problem is
  * FYI: PARANOIA_CB_READ & PARANOIA_CB_VERIFY happen continusly when ripping
